<?php
require_once '../includes/config.php';
require_once '../includes/auth.php';

checkAdminAuth();

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'add':
                addExpense($_POST);
                break;
            case 'edit':
                updateExpense($_POST);
                break;
            case 'delete':
                deleteExpense($_POST['expense_id']);
                break;
        }
    }
}

$expenses = getExpenses();
?>

<!DOCTYPE html>
<html dir="rtl" lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة المصروفات | نظام إدارة المقاولات</title>
    <link rel="stylesheet" href="../assets/css/admin.css">
</head>
<body>
    <?php include 'includes/admin-header.php'; ?>
    
    <div class="expenses-container">
        <div class="add-expense-form">
            <h2>إضافة مصروف جديد</h2>
            <form method="POST" action="">
                <input type="hidden" name="action" value="add">
                
                <div class="form-group">
                    <label for="expense_type">نوع المصروف</label>
                    <select name="expense_type" id="expense_type" required>
                        <option value="cash">نقدي</option>
                        <option value="credit">آجل</option>
                    </select>
                </div>
                
                <div class="form-group">
                    <label for="amount">المبلغ</label>
                    <input type="number" step="0.01" name="amount" required>
                </div>
                
                <div class="form-group">
                    <label for="description">الوصف</label>
                    <textarea name="description" required></textarea>
                </div>
                
                <div class="form-group">
                    <label for="project_id">المشروع</label>
                    <select name="project_id" required>
                        <?php foreach(getProjects() as $project): ?>
                            <option value="<?php echo $project['id']; ?>">
                                <?php echo $project['name']; ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                
                <button type="submit" class="btn-submit">إضافة المصروف</button>
            </form>
        </div>
        
        <div class="expenses-list">
            <h2>قائمة المصروفات</h2>
            <table>
                <thead>
                    <tr>
                        <th>التاريخ</th>
                        <th>النوع</th>
                        <th>المبلغ</th>
                        <th>الوصف</th>
                        <th>المشروع</th>
                        <th>الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach($expenses as $expense): ?>
                    <tr>
                        <td><?php echo $expense['date']; ?></td>
                        <td><?php echo $expense['type']; ?></td>
                        <td><?php echo number_format($expense['amount'], 2); ?></td>
                        <td><?php echo $expense['description']; ?></td>
                        <td><?php echo $expense['project_name']; ?></td>
                        <td>
                            <button onclick="editExpense(<?php echo $expense['id']; ?>)">تعديل</button>
                            <button onclick="deleteExpense(<?php echo $expense['id']; ?>)">حذف</button>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
    
    <script src="../assets/js/expenses.js"></script>
</body>
</html>