<?php
require_once '../includes/config.php';
require_once '../includes/auth.php';

checkAdminAuth();

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    updatePermissions($_POST);
}

$roles = getRoles();
$permissions = getAllPermissions();
?>

<!DOCTYPE html>
<html dir="rtl" lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة الصلاحيات | نظام إدارة المقاولات</title>
    <link rel="stylesheet" href="../assets/css/admin.css">
</head>
<body>
    <?php include 'includes/admin-header.php'; ?>
    
    <div class="permissions-container">
        <div class="roles-section">
            <h2>إدارة الأدوار والصلاحيات</h2>
            
            <div class="add-role">
                <form method="POST" action="">
                    <input type="hidden" name="action" value="add_role">
                    <div class="form-group">
                        <label>اسم الدور الجديد</label>
                        <input type="text" name="role_name" required>
                    </div>
                    <button type="submit">إضافة دور جديد</button>
                </form>
            </div>
            
            <form method="POST" action="" class="permissions-form">
                <table class="permissions-table">
                    <thead>
                        <tr>
                            <th>الصلاحية</th>
                            <?php foreach($roles as $role): ?>
                            <th><?php echo $role['name']; ?></th>
                            <?php endforeach; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach($permissions as $permission): ?>
                        <tr>
                            <td><?php echo $permission['description']; ?></td>
                            <?php foreach($roles as $role): ?>
                            <td>
                                <input type="checkbox" 
                                       name="permissions[<?php echo $role['id']; ?>][<?php echo $permission['id']; ?>]"
                                       <?php echo hasPermission($role['id'], $permission['id']) ? 'checked' : ''; ?>>
                            </td>
                            <?php endforeach; ?>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
                
                <button type="submit" class="btn-save">حفظ الصلاحيات</button>
            </form>
        </div>
        
        <div class="user-permissions">
            <h2>صلاحيات المستخدمين</h2>
            <table class="users-table">
                <thead>
                    <tr>
                        <th>اسم المستخدم</th>
                        <th>الدور</th>
                        <th>الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach(getUsers() as $user): ?>
                    <tr>
                        <td><?php echo $user['username']; ?></td>
                        <td>
                            <select name="user_role[<?php echo $user['id']; ?>]" 
                                    onchange="updateUserRole(<?php echo $user['id']; ?>, this.value)">
                                <?php foreach($roles as $role): ?>
                                <option value="<?php echo $role['id']; ?>" 
                                        <?php echo $user['role_id'] == $role['id'] ? 'selected' : ''; ?>>
                                    <?php echo $role['name']; ?>
                                </option>
                                <?php endforeach; ?>
                            </select>
                        </td>
                        <td>
                            <button onclick="viewUserPermissions(<?php echo $user['id']; ?>)">عرض الصلاحيات</button>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
    
    <script src="../assets/js/permissions.js"></script>
</body>
</html>