<?php
require_once '../includes/config.php';
require_once '../includes/auth.php';

checkAdminAuth();

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    switch ($_POST['action']) {
        case 'add':
            addProject($_POST);
            break;
        case 'update':
            updateProject($_POST);
            break;
        case 'delete':
            deleteProject($_POST['project_id']);
            break;
    }
}

$projects = getAllProjects();
?>

<!DOCTYPE html>
<html dir="rtl" lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة المشاريع | نظام إدارة المقاولات</title>
    <link rel="stylesheet" href="../assets/css/admin.css">
</head>
<body>
    <?php include 'includes/admin-header.php'; ?>
    
    <div class="projects-container">
        <div class="add-project-section">
            <h2>إضافة مشروع جديد</h2>
            <form method="POST" action="" enctype="multipart/form-data">
                <input type="hidden" name="action" value="add">
                
                <div class="form-group">
                    <label>اسم المشروع</label>
                    <input type="text" name="project_name" required>
                </div>
                
                <div class="form-group">
                    <label>وصف المشروع</label>
                    <textarea name="description" required></textarea>
                </div>
                
                <div class="form-group">
                    <label>قيمة العقد</label>
                    <input type="number" step="0.01" name="contract_value" required>
                </div>
                
                <div class="form-group">
                    <label>تاريخ البداية</label>
                    <input type="date" name="start_date" required>
                </div>
                
                <div class="form-group">
                    <label>تاريخ التسليم المتوقع</label>
                    <input type="date" name="expected_end_date" required>
                </div>
                
                <div class="form-group">
                    <label>العميل</label>
                    <input type="text" name="client_name" required>
                </div>
                
                <div class="form-group">
                    <label>الموقع</label>
                    <input type="text" name="location" required>
                </div>
                
                <div class="form-group">
                    <label>ملفات المشروع</label>
                    <input type="file" name="project_files[]" multiple>
                </div>
                
                <button type="submit" class="btn-submit">إضافة المشروع</button>
            </form>
        </div>
        
        <div class="projects-list">
            <h2>قائمة المشاريع</h2>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>اسم المشروع</th>
                        <th>العميل</th>
                        <th>قيمة العقد</th>
                        <th>تاريخ البداية</th>
                        <th>تاريخ التسليم</th>
                        <th>نسبة الإنجاز</th>
                        <th>الحالة</th>
                        <th>الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach($projects as $project): ?>
                    <tr>
                        <td><?php echo $project['project_name']; ?></td>
                        <td><?php echo $project['client_name']; ?></td>
                        <td><?php echo number_format($project['contract_value'], 2); ?></td>
                        <td><?php echo $project['start_date']; ?></td>
                        <td><?php echo $project['expected_end_date']; ?></td>
                        <td>
                            <div class="progress-bar">
                                <div class="progress" style="width: <?php echo $project['progress']; ?>%">
                                    <?php echo $project['progress']; ?>%
                                </div>
                            </div>
                        </td>
                        <td><?php echo $project['status']; ?></td>
                        <td>
                            <button onclick="editProject(<?php echo $project['id']; ?>)">تعديل</button>
                            <button onclick="viewProjectDetails(<?php echo $project['id']; ?>)">التفاصيل</button>
                            <button onclick="deleteProject(<?php echo $project['id']; ?>)">حذف</button>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
    
    <script src="../assets/js/projects.js"></script>
</body>
</html>