<?php
require_once '../includes/config.php';
require_once '../includes/auth.php';

checkAdminAuth();

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    switch ($_POST['action']) {
        case 'add':
            $worker_code = generateWorkerCode(); // توليد كود فريد للعامل
            addWorker($_POST, $worker_code);
            break;
        case 'update':
            updateWorker($_POST);
            break;
        case 'delete':
            deleteWorker($_POST['worker_id']);
            break;
    }
}

$workers = getAllWorkers();
?>

<!DOCTYPE html>
<html dir="rtl" lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة العمال | نظام إدارة المقاولات</title>
    <link rel="stylesheet" href="../assets/css/admin.css">
</head>
<body>
    <?php include 'includes/admin-header.php'; ?>
    
    <div class="workers-container">
        <div class="add-worker-section">
            <h2>إضافة عامل جديد</h2>
            <form method="POST" action="" enctype="multipart/form-data">
                <input type="hidden" name="action" value="add">
                
                <div class="form-group">
                    <label>الاسم الكامل</label>
                    <input type="text" name="full_name" required>
                </div>
                
                <div class="form-group">
                    <label>رقم الهوية</label>
                    <input type="text" name="id_number" required>
                </div>
                
                <div class="form-group">
                    <label>رقم الجوال</label>
                    <input type="tel" name="phone" required>
                </div>
                
                <div class="form-group">
                    <label>المهنة</label>
                    <input type="text" name="job_title" required>
                </div>
                
                <div class="form-group">
                    <label>الراتب اليومي</label>
                    <input type="number" name="daily_wage" required>
                </div>
                
                <div class="form-group">
                    <label>صورة شخصية</label>
                    <input type="file" name="photo" accept="image/*">
                </div>
                
                <button type="submit" class="btn-submit">إضافة العامل</button>
            </form>
        </div>
        
        <div class="workers-list">
            <h2>قائمة العمال</h2>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>كود العامل</th>
                        <th>الاسم</th>
                        <th>رقم الهوية</th>
                        <th>الجوال</th>
                        <th>المهنة</th>
                        <th>الراتب اليومي</th>
                        <th>الحالة</th>
                        <th>الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach($workers as $worker): ?>
                    <tr>
                        <td><?php echo $worker['worker_code']; ?></td>
                        <td><?php echo $worker['full_name']; ?></td>
                        <td><?php echo $worker['id_number']; ?></td>
                        <td><?php echo $worker['phone']; ?></td>
                        <td><?php echo $worker['job_title']; ?></td>
                        <td><?php echo number_format($worker['daily_wage'], 2); ?></td>
                        <td><?php echo $worker['status']; ?></td>
                        <td>
                            <button onclick="editWorker(<?php echo $worker['id']; ?>)">تعديل</button>
                            <button onclick="viewWorkerDetails(<?php echo $worker['id']; ?>)">التفاصيل</button>
                            <button onclick="deleteWorker(<?php echo $worker['id']; ?>)">حذف</button>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
    
    <script src="../assets/js/workers.js"></script>
</body>
</html>