<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

// التحقق من الصلاحيات
if (!$auth->hasPermission('manage_expenses')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

// التحقق من وجود المعرف
$id = $_GET['id'] ?? null;
if (!$id) {
    http_response_code(400);
    echo json_encode(['error' => 'معرف المصروف مطلوب']);
    exit;
}

switch ($_SERVER['REQUEST_METHOD']) {
    case 'GET':
        // جلب تفاصيل المصروف
        try {
            $expense = getRow("
                SELECT 
                    e.*,
                    p.name as project_name,
                    u.username as created_by_user
                FROM expenses e
                LEFT JOIN projects p ON e.project_id = p.id
                LEFT JOIN users u ON e.created_by = u.id
                WHERE e.id = ?
            ", [$id]);

            if (!$expense) {
                http_response_code(404);
                echo json_encode(['error' => 'المصروف غير موجود']);
                exit;
            }

            echo json_encode([
                'status' => 'success',
                'data' => $expense
            ]);
        } catch (Exception $e) {
            http_response_code(500);
            echo json_encode(['error' => 'خطأ في جلب البيانات']);
        }
        break;

    case 'PUT':
        // تحديث المصروف
        try {
            $data = json_decode(file_get_contents('php://input'), true);
            
            // التحقق من وجود المصروف
            $current_expense = getRow("
                SELECT * FROM expenses WHERE id = ?
            ", [$id]);

            if (!$current_expense) {
                http_response_code(404);
                echo json_encode(['error' => 'المصروف غير موجود']);
                exit;
            }

            $db->beginTransaction();

            // تحديث المصروف
            $expense_data = [
                'amount' => $data['amount'] ?? $current_expense['amount'],
                'type' => $data['type'] ?? $current_expense['type'],
                'date' => $data['date'] ?? $current_expense['date'],
                'description' => $data['description'] ?? $current_expense['description'],
                'updated_by' => $_SESSION['user_id'],
                'updated_at' => date('Y-m-d H:i:s')
            ];

            $db->update('expenses', $expense_data, 'id = ?', [$id]);

            // تحديث ميزانية المشروع إذا تغير المبلغ
            if (isset($data['amount']) && $current_expense['project_id']) {
                $difference = $data['amount'] - $current_expense['amount'];
                $db->query("
                    UPDATE projects 
                    SET total_expenses = total_expenses + ?,
                        updated_at = NOW()
                    WHERE id = ?
                ", [$difference, $current_expense['project_id']]);
            }

            // تحديث المعاملة المالية
            $db->update(
                'financial_transactions',
                ['amount' => $data['amount'] ?? $current_expense['amount']],
                'reference_id = ? AND reference_type = ?',
                [$id, 'expense']
            );

            $db->commit();

            echo json_encode([
                'status' => 'success',
                'message' => 'تم تحديث المصروف بنجاح'
            ]);
        } catch (Exception $e) {
            $db->rollback();
            http_response_code(400);
            echo json_encode(['error' => $e->getMessage()]);
        }
        break;

    case 'DELETE':
        // حذف المصروف
        try {
            // التحقق من وجود المصروف
            $expense = getRow("SELECT * FROM expenses WHERE id = ?", [$id]);
            if (!$expense) {
                http_response_code(404);
                echo json_encode(['error' => 'المصروف غير موجود']);
                exit;
            }

            $db->beginTransaction();

            // تحديث ميزانية المشروع
            if ($expense['project_id']) {
                $db->query("
                    UPDATE projects 
                    SET total_expenses = total_expenses - ?,
                        updated_at = NOW()
                    WHERE id = ?
                ", [$expense['amount'], $expense['project_id']]);
            }

            // حذف المعاملة المالية
            $db->delete(
                'financial_transactions',
                'reference_id = ? AND reference_type = ?',
                [$id, 'expense']
            );

            // حذف المصروف
            $db->delete('expenses', 'id = ?', [$id]);

            $db->commit();

            echo json_encode([
                'status' => 'success',
                'message' => 'تم حذف المصروف بنجاح'
            ]);
        } catch (Exception $e) {
            $db->rollback();
            http_response_code(400);
            echo json_encode(['error' => $e->getMessage()]);
        }
        break;

    default:
        http_response_code(405);
        echo json_encode(['error' => 'طريقة الطلب غير مدعومة']);
}