<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

// التحقق من الصلاحيات
if (!$auth->hasPermission('manage_expenses')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

switch ($_SERVER['REQUEST_METHOD']) {
    case 'GET':
        // جلب المصروفات
        try {
            $where = "1=1";
            $params = [];
            
            // فلترة حسب التاريخ
            if (isset($_GET['start_date'])) {
                $where .= " AND date >= ?";
                $params[] = $_GET['start_date'];
            }
            if (isset($_GET['end_date'])) {
                $where .= " AND date <= ?";
                $params[] = $_GET['end_date'];
            }
            
            // فلترة حسب النوع
            if (isset($_GET['type'])) {
                $where .= " AND type = ?";
                $params[] = $_GET['type'];
            }
            
            // فلترة حسب المشروع
            if (isset($_GET['project_id'])) {
                $where .= " AND project_id = ?";
                $params[] = $_GET['project_id'];
            }

            $query = "
                SELECT 
                    e.*,
                    p.name as project_name,
                    u.username as created_by_user
                FROM expenses e
                LEFT JOIN projects p ON e.project_id = p.id
                LEFT JOIN users u ON e.created_by = u.id
                WHERE $where
                ORDER BY e.date DESC
            ";

            $expenses = getAll($query, $params);
            
            echo json_encode([
                'status' => 'success',
                'data' => $expenses
            ]);
        } catch (Exception $e) {
            http_response_code(500);
            echo json_encode(['error' => 'خطأ في جلب البيانات']);
        }
        break;

    case 'POST':
        // إضافة مصروف جديد
        try {
            $data = json_decode(file_get_contents('php://input'), true);
            
            // التحقق من البيانات المطلوبة
            $required_fields = ['amount', 'type', 'date', 'description'];
            foreach ($required_fields as $field) {
                if (!isset($data[$field]) || empty($data[$field])) {
                    throw new Exception("حقل {$field} مطلوب");
                }
            }

            $db->beginTransaction();

            // إضافة المصروف
            $expense_data = [
                'amount' => $data['amount'],
                'type' => $data['type'],
                'date' => $data['date'],
                'description' => $data['description'],
                'project_id' => $data['project_id'] ?? null,
                'created_by' => $_SESSION['user_id'],
                'created_at' => date('Y-m-d H:i:s')
            ];

            $db->insert('expenses', $expense_data);
            $expense_id = $db->lastInsertId();

            // إذا كان المصروف مرتبط بمشروع، تحديث الميزانية
            if (isset($data['project_id'])) {
                $db->query("
                    UPDATE projects 
                    SET total_expenses = total_expenses + ?,
                        updated_at = NOW()
                    WHERE id = ?
                ", [$data['amount'], $data['project_id']]);
            }

            // تسجيل المعاملة المالية
            $transaction_data = [
                'type' => 'expense',
                'amount' => $data['amount'],
                'reference_id' => $expense_id,
                'reference_type' => 'expense',
                'description' => $data['description'],
                'created_by' => $_SESSION['user_id'],
                'created_at' => date('Y-m-d H:i:s')
            ];
            $db->insert('financial_transactions', $transaction_data);

            $db->commit();

            echo json_encode([
                'status' => 'success',
                'message' => 'تم إضافة المصروف بنجاح',
                'data' => ['id' => $expense_id]
            ]);
        } catch (Exception $e) {
            $db->rollback();
            http_response_code(400);
            echo json_encode(['error' => $e->getMessage()]);
        }
        break;

    default:
        http_response_code(405);
        echo json_encode(['error' => 'طريقة الطلب غير مدعومة']);
}