<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

// التحقق من الصلاحيات
if (!$auth->hasPermission('view_expenses')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

try {
    $period = $_GET['period'] ?? 'monthly';
    
    switch ($period) {
        case 'daily':
            $group_by = 'DATE(date)';
            $limit = 30;
            break;
        case 'monthly':
            $group_by = 'DATE_FORMAT(date, "%Y-%m")';
            $limit = 12;
            break;
        case 'yearly':
            $group_by = 'YEAR(date)';
            $limit = 5;
            break;
        default:
            throw new Exception('فترة غير صالحة');
    }

    $summary = getAll("
        SELECT 
            {$group_by} as period,
            COUNT(*) as count,
            SUM(amount) as total_amount,
            AVG(amount) as average_amount,
            MIN(amount) as min_amount,
            MAX(amount) as max_amount
        FROM expenses 
        GROUP BY period
        ORDER BY period DESC
        LIMIT {$limit}
    ");

    // إحصائيات إضافية
    $stats = getRow("
        SELECT 
            COUNT(*) as total_count,
            SUM(amount) as total_amount,
            AVG(amount) as average_amount,
            MIN(amount) as min_amount,
            MAX(amount) as max_amount
        FROM expenses
    ");

    echo json_encode([
        'status' => 'success',
        'data' => [
            'summary' => $summary,
            'stats' => $stats
        ]
    ]);
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(['error' => $e->getMessage()]);
}