<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

// التحقق من الصلاحيات
if (!$auth->hasPermission('manage_projects')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405);
    echo json_encode(['error' => 'طريقة الطلب غير مدعومة']);
    exit;
}

try {
    $data = json_decode(file_get_contents('php://input'), true);
    
    // التحقق من البيانات المطلوبة
    if (!isset($data['project_id']) || !isset($data['amount']) || !isset($data['type'])) {
        throw new Exception('البيانات غير مكتملة');
    }

    // التحقق من وجود المشروع
    $project = getRow("SELECT * FROM projects WHERE id = ?", [$data['project_id']]);
    if (!$project) {
        throw new Exception('المشروع غير موجود');
    }

    // تحديث الميزانية حسب النوع (إضافة أو خصم)
    $new_budget = $project['budget'];
    if ($data['type'] === 'add') {
        $new_budget += $data['amount'];
    } elseif ($data['type'] === 'subtract') {
        $new_budget -= $data['amount'];
    } else {
        throw new Exception('نوع العملية غير صالح');
    }

    // تحديث الميزانية
    $db->update('projects', 
        ['budget' => $new_budget, 'updated_at' => date('Y-m-d H:i:s')],
        'id = ?', 
        [$data['project_id']]
    );

    echo json_encode([
        'status' => 'success',
        'message' => 'تم تحديث الميزانية بنجاح',
        'data' => ['new_budget' => $new_budget]
    ]);
} catch (Exception $e) {
    http_response_code(400);
    echo json_encode(['error' => $e->getMessage()]);
}