<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

// التحقق من الصلاحيات
if (!$auth->hasPermission('manage_projects')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405);
    echo json_encode(['error' => 'طريقة الطلب غير مدعومة']);
    exit;
}

try {
    $data = json_decode(file_get_contents('php://input'), true);
    
    // التحقق من البيانات المطلوبة
    if (!isset($data['project_id']) || !isset($data['description'])) {
        throw new Exception('البيانات غير مكتملة');
    }

    // التحقق من وجود المشروع
    $project = getRow("SELECT * FROM projects WHERE id = ?", [$data['project_id']]);
    if (!$project) {
        throw new Exception('المشروع غير موجود');
    }

    $db->beginTransaction();

    // إضافة التحديث
    $update_data = [
        'project_id' => $data['project_id'],
        'description' => $data['description'],
        'update_date' => date('Y-m-d H:i:s'),
        'created_by' => $_SESSION['user_id']
    ];

    $db->insert('project_updates', $update_data);

    // تحديث حالة المشروع إذا تم تحديدها
    if (isset($data['status'])) {
        $db->update('projects', 
            ['status' => $data['status'], 'updated_at' => date('Y-m-d H:i:s')],
            'id = ?', 
            [$data['project_id']]
        );
    }

    $db->commit();

    echo json_encode([
        'status' => 'success',
        'message' => 'تم إضافة التحديث بنجاح'
    ]);
} catch (Exception $e) {
    $db->rollback();
    http_response_code(400);
    echo json_encode(['error' => $e->getMessage()]);
}