<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

// التحقق من الصلاحيات
if (!$auth->hasPermission('view_reports')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

try {
    $period = $_GET['period'] ?? 'monthly';
    $start_date = $_GET['start_date'] ?? date('Y-m-01');
    $end_date = $_GET['end_date'] ?? date('Y-m-t');
    
    $db->beginTransaction();

    // ملخص المصروفات والإيرادات
    $financial_summary = getRow("
        SELECT 
            SUM(CASE WHEN type = 'expense' THEN amount ELSE 0 END) as total_expenses,
            SUM(CASE WHEN type = 'income' THEN amount ELSE 0 END) as total_income,
            COUNT(DISTINCT project_id) as projects_count
        FROM financial_transactions
        WHERE date BETWEEN ? AND ?
    ", [$start_date, $end_date]);

    // تفاصيل المصروفات حسب النوع
    $expenses_by_type = getAll("
        SELECT 
            expense_type,
            COUNT(*) as count,
            SUM(amount) as total_amount,
            AVG(amount) as avg_amount
        FROM expenses
        WHERE date BETWEEN ? AND ?
        GROUP BY expense_type
        ORDER BY total_amount DESC
    ", [$start_date, $end_date]);

    // تفاصيل المشاريع المالية
    $projects_financial = getAll("
        SELECT 
            p.id,
            p.name,
            p.budget,
            SUM(e.amount) as total_expenses,
            (p.budget - SUM(e.amount)) as remaining_budget,
            (SUM(e.amount) / p.budget * 100) as budget_usage_percentage
        FROM projects p
        LEFT JOIN expenses e ON p.id = e.project_id
        WHERE p.start_date BETWEEN ? AND ?
        GROUP BY p.id
        ORDER BY budget_usage_percentage DESC
    ", [$start_date, $end_date]);

    // تحليل التدفق النقدي
    $cash_flow = getAll("
        SELECT 
            DATE_FORMAT(date, '%Y-%m') as month,
            SUM(CASE WHEN type = 'income' THEN amount ELSE 0 END) as income,
            SUM(CASE WHEN type = 'expense' THEN amount ELSE 0 END) as expenses,
            SUM(CASE WHEN type = 'income' THEN amount ELSE -amount END) as net_flow
        FROM financial_transactions
        WHERE date BETWEEN ? AND ?
        GROUP BY month
        ORDER BY month
    ", [$start_date, $end_date]);

    // مؤشرات الأداء المالية
    $kpis = [
        'profit_margin' => ($financial_summary['total_income'] - $financial_summary['total_expenses']) / 
                          ($financial_summary['total_income'] ?: 1) * 100,
        'average_project_cost' => $financial_summary['total_expenses'] / 
                                ($financial_summary['projects_count'] ?: 1),
        'expense_ratio' => $financial_summary['total_expenses'] / 
                          ($financial_summary['total_income'] ?: 1) * 100
    ];

    $db->commit();

    echo json_encode([
        'status' => 'success',
        'data' => [
            'summary' => $financial_summary,
            'expenses_by_type' => $expenses_by_type,
            'projects_financial' => $projects_financial,
            'cash_flow' => $cash_flow,
            'kpis' => $kpis
        ]
    ]);
} catch (Exception $e) {
    $db->rollback();
    http_response_code(500);
    echo json_encode(['error' => 'خطأ في إنشاء التقرير']);
}