<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

if (!$auth->hasPermission('view_reports')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

try {
    $start_date = $_GET['start_date'] ?? date('Y-m-01');
    $end_date = $_GET['end_date'] ?? date('Y-m-t');

    // ملخص حالة المشاريع
    $projects_summary = getRow("
        SELECT 
            COUNT(*) as total_projects,
            SUM(CASE WHEN status = 'completed' THEN 1 ELSE 0 END) as completed_projects,
            SUM(CASE WHEN status = 'in_progress' THEN 1 ELSE 0 END) as active_projects,
            SUM(CASE WHEN status = 'delayed' THEN 1 ELSE 0 END) as delayed_projects,
            AVG(DATEDIFF(end_date, start_date)) as avg_duration
        FROM projects
        WHERE start_date BETWEEN ? AND ?
    ", [$start_date, $end_date]);

    // تحليل المشاريع حسب العميل
    $projects_by_client = getAll("
        SELECT 
            c.name as client_name,
            COUNT(*) as projects_count,
            SUM(p.budget) as total_budget,
            AVG(DATEDIFF(p.end_date, p.start_date)) as avg_duration
        FROM projects p
        JOIN clients c ON p.client_id = c.id
        WHERE p.start_date BETWEEN ? AND ?
        GROUP BY c.id
        ORDER BY projects_count DESC
    ", [$start_date, $end_date]);

    // تحليل العمال في المشاريع
    $workers_analysis = getAll("
        SELECT 
            p.id,
            p.name as project_name,
            COUNT(DISTINCT pw.worker_id) as workers_count,
            SUM(w.hourly_rate * a.hours_worked) as labor_cost
        FROM projects p
        LEFT JOIN project_workers pw ON p.id = pw.project_id
        LEFT JOIN workers w ON pw.worker_id = w.id
        LEFT JOIN attendance a ON w.id = a.worker_id
        WHERE p.start_date BETWEEN ? AND ?
        GROUP BY p.id
        ORDER BY labor_cost DESC
    ", [$start_date, $end_date]);

    // تحليل تقدم المشاريع
    $progress_analysis = getAll("
        SELECT 
            p.id,
            p.name,
            p.status,
            DATEDIFF(CURDATE(), p.start_date) as days_from_start,
            DATEDIFF(p.end_date, CURDATE()) as days_remaining,
            (DATEDIFF(CURDATE(), p.start_date) / DATEDIFF(p.end_date, p.start_date) * 100) as time_progress,
            (SELECT COUNT(*) FROM project_updates WHERE project_id = p.id) as updates_count
        FROM projects p
        WHERE p.start_date BETWEEN ? AND ?
        ORDER BY time_progress DESC
    ", [$start_date, $end_date]);

    // مؤشرات الأداء الرئيسية
    $kpis = [
        'completion_rate' => ($projects_summary['completed_projects'] / $projects_summary['total_projects']) * 100,
        'delay_rate' => ($projects_summary['delayed_projects'] / $projects_summary['total_projects']) * 100,
        'avg_duration' => $projects_summary['avg_duration']
    ];

    echo json_encode([
        'status' => 'success',
        'data' => [
            'summary' => $projects_summary,
            'by_client' => $projects_by_client,
            'workers_analysis' => $workers_analysis,
            'progress_analysis' => $progress_analysis,
            'kpis' => $kpis
        ]
    ]);
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(['error' => 'خطأ في إنشاء التقرير']);
}