<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

// التحقق من الصلاحيات
if (!$auth->hasPermission('manage_workers')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

$id = $_GET['id'] ?? null;
if (!$id) {
    http_response_code(400);
    echo json_encode(['error' => 'معرف العامل مطلوب']);
    exit;
}

switch ($_SERVER['REQUEST_METHOD']) {
    case 'GET':
        // جلب تفاصيل العامل
        try {
            $worker = getRow("
                SELECT w.* 
                FROM workers w
                WHERE w.id = ?
            ", [$id]);

            if (!$worker) {
                http_response_code(404);
                echo json_encode(['error' => 'العامل غير موجود']);
                exit;
            }

            // إضافة المعلومات التفصيلية
            $worker['skills'] = getAll("
                SELECT s.* 
                FROM worker_skills ws
                JOIN skills s ON ws.skill_id = s.id
                WHERE ws.worker_id = ?
            ", [$id]);

            $worker['documents'] = getAll("
                SELECT * FROM worker_documents
                WHERE worker_id = ?
            ", [$id]);

            $worker['projects'] = getAll("
                SELECT p.* 
                FROM project_workers pw
                JOIN projects p ON pw.project_id = p.id
                WHERE pw.worker_id = ?
            ", [$id]);

            $worker['attendance'] = getAll("
                SELECT * FROM attendance
                WHERE worker_id = ?
                ORDER BY date DESC
                LIMIT 30
            ", [$id]);

            $worker['evaluations'] = getAll("
                SELECT * FROM worker_evaluations
                WHERE worker_id = ?
                ORDER BY evaluation_date DESC
            ", [$id]);

            echo json_encode([
                'status' => 'success',
                'data' => $worker
            ]);
        } catch (Exception $e) {
            http_response_code(500);
            echo json_encode(['error' => 'خطأ في جلب البيانات']);
        }
        break;

    case 'PUT':
        // تحديث بيانات العامل
        try {
            $data = json_decode(file_get_contents('php://input'), true);
            
            // التحقق من وجود العامل
            $worker = getRow("SELECT * FROM workers WHERE id = ?", [$id]);
            if (!$worker) {
                http_response_code(404);
                echo json_encode(['error' => 'العامل غير موجود']);
                exit;
            }

            $db->beginTransaction();

            // تحديث البيانات الأساسية
            $update_data = [
                'name' => $data['name'] ?? $worker['name'],
                'phone' => $data['phone'] ?? $worker['phone'],
                'email' => $data['email'] ?? $worker['email'],
                'address' => $data['address'] ?? $worker['address'],
                'job_title' => $data['job_title'] ?? $worker['job_title'],
                'hourly_rate' => $data['hourly_rate'] ?? $worker['hourly_rate'],
                'status' => $data['status'] ?? $worker['status'],
                'updated_by' => $_SESSION['user_id'],
                'updated_at' => date('Y-m-d H:i:s')
            ];

            $db->update('workers', $update_data, 'id = ?', [$id]);

            // تحديث المهارات
            if (isset($data['skills'])) {
                $db->delete('worker_skills', 'worker_id = ?', [$id]);
                foreach ($data['skills'] as $skill_id) {
                    $db->insert('worker_skills', [
                        'worker_id' => $id,
                        'skill_id' => $skill_id
                    ]);
                }
            }

            // تحديث المستندات
            if (!empty($data['new_documents'])) {
                foreach ($data['new_documents'] as $doc) {
                    $doc_path = uploadFile($doc, 'worker_documents');
                    $db->insert('worker_documents', [
                        'worker_id' => $id,
                        'type' => $doc['type'],
                        'file_path' => $doc_path,
                        'expiry_date' => $doc['expiry_date'] ?? null,
                        'created_at' => date('Y-m-d H:i:s')
                    ]);
                }
            }

            $db->commit();

            echo json_encode([
                'status' => 'success',
                'message' => 'تم تحديث بيانات العامل بنجاح'
            ]);
        } catch (Exception $e) {
            $db->rollback();
            http_response_code(400);
            echo json_encode(['error' => $e->getMessage()]);
        }
        break;

    case 'DELETE':
        // حذف العامل
        try {
            // التحقق من وجود العامل
            $worker = getRow("SELECT * FROM workers WHERE id = ?", [$id]);
            if (!$worker) {
                http_response_code(404);
                echo json_encode(['error' => 'العامل غير موجود']);
                exit;
            }

            $db->beginTransaction();

            // حذف المستندات
            $documents = getAll("SELECT file_path FROM worker_documents WHERE worker_id = ?", [$id]);
            foreach ($documents as $doc) {
                deleteFile($doc['file_path']);
            }
            $db->delete('worker_documents', 'worker_id = ?', [$id]);

            // حذف العلاقات
            $db->delete('worker_skills', 'worker_id = ?', [$id]);
            $db->delete('project_workers', 'worker_id = ?', [$id]);
            $db->delete('worker_evaluations', 'worker_id = ?', [$id]);
            
            // تحديث حالة العامل بدلاً من الحذف الفعلي
            $db->update('workers', 
                ['status' => 'deleted', 'deleted_at' => date('Y-m-d H:i:s')],
                'id = ?', 
                [$id]
            );

            $db->commit();

            echo json_encode([
                'status' => 'success',
                'message' => 'تم حذف العامل بنجاح'
            ]);
        } catch (Exception $e) {
            $db->rollback();
            http_response_code(400);
            echo json_encode(['error' => $e->getMessage()]);
        }
        break;

    default:
        http_response_code(405);
        echo json_encode(['error' => 'طريقة الطلب غير مدعومة']);
}