<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

if (!$auth->hasPermission('manage_attendance')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

switch ($_SERVER['REQUEST_METHOD']) {
    case 'POST':
        // تسجيل حضور أو انصراف
        try {
            $data = json_decode(file_get_contents('php://input'), true);
            
            if (!isset($data['worker_id']) || !isset($data['type'])) {
                throw new Exception('البيانات غير مكتملة');
            }

            $worker = getRow("SELECT * FROM workers WHERE id = ?", [$data['worker_id']]);
            if (!$worker) {
                throw new Exception('العامل غير موجود');
            }

            $today = date('Y-m-d');
            
            switch ($data['type']) {
                case 'check_in':
                    // التحقق من عدم وجود تسجيل حضور سابق لليوم
                    $exists = getValue("
                        SELECT COUNT(*) FROM attendance 
                        WHERE worker_id = ? AND DATE(check_in) = ?
                    ", [$data['worker_id'], $today]);

                    if ($exists) {
                        throw new Exception('تم تسجيل الحضور مسبقاً');
                    }

                    $db->insert('attendance', [
                        'worker_id' => $data['worker_id'],
                        'check_in' => date('Y-m-d H:i:s'),
                        'status' => 'present',
                        'created_by' => $_SESSION['user_id']
                    ]);
                    break;

                case 'check_out':
                    // تحديث وقت الانصراف وحساب ساعات العمل
                    $attendance = getRow("
                        SELECT * FROM attendance 
                        WHERE worker_id = ? AND DATE(check_in) = ?
                    ", [$data['worker_id'], $today]);

                    if (!$attendance) {
                        throw new Exception('لم يتم تسجيل الحضور');
                    }

                    if ($attendance['check_out']) {
                        throw new Exception('تم تسجيل الانصراف مسبقاً');
                    }

                    $check_out = date('Y-m-d H:i:s');
                    $hours_worked = round((strtotime($check_out) - strtotime($attendance['check_in'])) / 3600, 2);

                    $db->update('attendance', 
                        [
                            'check_out' => $check_out,
                            'hours_worked' => $hours_worked,
                            'updated_by' => $_SESSION['user_id']
                        ],
                        'id = ?',
                        [$attendance['id']]
                    );
                    break;

                default:
                    throw new Exception('نوع العملية غير صالح');
            }

            echo json_encode([
                'status' => 'success',
                'message' => 'تم تسجيل العملية بنجاح'
            ]);
        } catch (Exception $e) {
            http_response_code(400);
            echo json_encode(['error' => $e->getMessage()]);
        }
        break;

    case 'GET':
        // جلب سجل الحضور
        try {
            $where = "1=1";
            $params = [];
            
            if (isset($_GET['worker_id'])) {
                $where .= " AND a.worker_id = ?";
                $params[] = $_GET['worker_id'];
            }
            
            if (isset($_GET['start_date'])) {
                $where .= " AND DATE(a.check_in) >= ?";
                $params[] = $_GET['start_date'];
            }
            
            if (isset($_GET['end_date'])) {
                $where .= " AND DATE(a.check_in) <= ?";
                $params[] = $_GET['end_date'];
            }

            $attendance = getAll("
                SELECT 
                    a.*,
                    w.name as worker_name,
                    w.job_title
                FROM attendance a
                JOIN workers w ON a.worker_id = w.id
                WHERE $where
                ORDER BY a.check_in DESC
            ", $params);

            echo json_encode([
                'status' => 'success',
                'data' => $attendance
            ]);
        } catch (Exception $e) {
            http_response_code(500);
            echo json_encode(['error' => 'خطأ في جلب البيانات']);
        }
        break;

    default:
        http_response_code(405);
        echo json_encode(['error' => 'طريقة الطلب غير مدعومة']);
}