<?php
require_once '../includes/config.php';
require_once '../includes/auth.php';

checkWorkerAuth();

$worker_id = $_SESSION['worker_id'];
$date = $_GET['date'] ?? date('Y-m-d');

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'add_record':
                addDailyRecord($_POST, $worker_id);
                break;
            case 'update_record':
                updateDailyRecord($_POST);
                break;
        }
    }
}

$daily_records = getDailyRecords($worker_id, $date);
$projects = getWorkerActiveProjects($worker_id);
?>

<!DOCTYPE html>
<html dir="rtl" lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>تسجيل اليوميات | بوابة العمال</title>
    <link rel="stylesheet" href="../assets/css/workers.css">
</head>
<body>
    <?php include 'includes/worker-header.php'; ?>
    
    <div class="daily-records-container">
        <div class="date-selector">
            <form method="GET" action="">
                <label>اختر التاريخ:</label>
                <input type="date" name="date" value="<?php echo $date; ?>" 
                       onchange="this.form.submit()">
            </form>
        </div>
        
        <div class="add-record-section">
            <h2>تسجيل عمل جديد</h2>
            <form method="POST" action="">
                <input type="hidden" name="action" value="add_record">
                
                <div class="form-group">
                    <label>المشروع</label>
                    <select name="project_id" required>
                        <?php foreach($projects as $project): ?>
                        <option value="<?php echo $project['id']; ?>">
                            <?php echo $project['name']; ?>
                        </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                
                <div class="form-group">
                    <label>نوع العمل</label>
                    <input type="text" name="work_type" required>
                </div>
                
                <div class="form-group">
                    <label>وصف العمل</label>
                    <textarea name="description" required></textarea>
                </div>
                
                <div class="form-group">
                    <label>عدد ساعات العمل</label>
                    <input type="number" name="hours_worked" min="1" max="24" required>
                </div>
                
                <div class="form-group">
                    <label>الموقع</label>
                    <input type="text" name="location" required>
                </div>
                
                <button type="submit" class="btn-submit">تسجيل العمل</button>
            </form>
        </div>
        
        <div class="records-list">
            <h2>سجل اليوم: <?php echo date('Y-m-d', strtotime($date)); ?></h2>
            
            <?php if(empty($daily_records)): ?>
                <p class="no-records">لا توجد سجلات لهذا اليوم</p>
            <?php else: ?>
                <div class="records-grid">
                    <?php foreach($daily_records as $record): ?>
                    <div class="record-card">
                        <div class="record-header">
                            <h3><?php echo $record['project_name']; ?></h3>
                            <span class="time"><?php echo $record['created_at']; ?></span>
                        </div>
                        
                        <div class="record-details">
                            <p><strong>نوع العمل:</strong> <?php echo $record['work_type']; ?></p>
                            <p><strong>الوصف:</strong> <?php echo $record['description']; ?></p>
                            <p><strong>ساعات العمل:</strong> <?php echo $record['hours_worked']; ?></p>
                            <p><strong>الموقع:</strong> <?php echo $record['location']; ?></p>
                        </div>
                        
                        <?php if(date('Y-m-d') == $date): ?>
                        <div class="record-actions">
                            <button onclick="editRecord(<?php echo $record['id']; ?>)">
                                تعديل
                            </button>
                        </div>
                        <?php endif; ?>
                    </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
    </div>
    
    <script src="../assets/js/daily-records.js"></script>
</body>
</html>