<?php
require_once '../includes/config.php';
require_once '../includes/auth.php';

checkWorkerAuth();

$project_id = $_GET['id'] ?? null;
$worker_id = $_SESSION['worker_id'];

if($project_id) {
    $project = getProjectDetails($project_id);
    $tasks = getWorkerProjectTasks($worker_id, $project_id);
} else {
    $projects = getAllWorkerProjects($worker_id);
}
?>

<!DOCTYPE html>
<html dir="rtl" lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>المشاريع | بوابة العمال</title>
    <link rel="stylesheet" href="../assets/css/workers.css">
</head>
<body>
    <?php include 'includes/worker-header.php'; ?>
    
    <div class="projects-container">
        <?php if($project_id): ?>
            <!-- تفاصيل مشروع محدد -->
            <div class="project-details">
                <h2><?php echo $project['name']; ?></h2>
                
                <div class="project-info">
                    <div class="info-item">
                        <label>الموقع:</label>
                        <span><?php echo $project['location']; ?></span>
                    </div>
                    <div class="info-item">
                        <label>تاريخ البداية:</label>
                        <span><?php echo $project['start_date']; ?></span>
                    </div>
                    <div class="info-item">
                        <label>نسبة الإنجاز:</label>
                        <div class="progress-bar">
                            <div class="progress" style="width: <?php echo $project['progress']; ?>%">
                                <?php echo $project['progress']; ?>%
                            </div>
                        </div>
                    </div>
                </div>
                
                <div class="tasks-section">
                    <h3>المهام المسندة</h3>
                    <div class="tasks-list">
                        <?php foreach($tasks as $task): ?>
                        <div class="task-item <?php echo $task['status']; ?>">
                            <h4><?php echo $task['title']; ?></h4>
                            <p><?php echo $task['description']; ?></p>
                            <div class="task-status">
                                <span>الحالة: <?php echo $task['status']; ?></span>
                                <?php if($task['status'] != 'completed'): ?>
                                <button onclick="updateTaskStatus(<?php echo $task['id']; ?>)">
                                    تحديث الحالة
                                </button>
                                <?php endif; ?>
                            </div>
                        </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        <?php else: ?>
            <!-- قائمة جميع المشاريع -->
            <h2>المشاريع المتاحة</h2>
            <div class="projects-grid">
                <?php foreach($projects as $project): ?>
                <div class="project-card">
                    <h3><?php echo $project['name']; ?></h3>
                    <p class="location"><?php echo $project['location']; ?></p>
                    <div class="progress-bar">
                        <div class="progress" style="width: <?php echo $project['progress']; ?>%">
                            <?php echo $project['progress']; ?>%
                        </div>
                    </div>
                    <div class="project-status">
                        <span class="status-badge <?php echo $project['status']; ?>">
                            <?php echo $project['status']; ?>
                        </span>
                    </div>
                    <a href="?id=<?php echo $project['id']; ?>" class="btn-details">
                        عرض التفاصيل
                    </a>
                </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>
    </div>
    
    <script src="../assets/js/worker-projects.js"></script>
</body>
</html>